@@ -35,3 +35,11 @@ test.zero_width_xts_to_matrix <- function() {
   zm <- as.matrix(as.zoo(x))
   checkIdentical(xm, zm)
 }
+
+# dim-less xts to matrix
+test.dimless_xts_to_matrix <- function() {
+  ix <- structure(1:3, tclass = c("POSIXct", "POSIXt"), tzone = "")
+  x <- structure(1:3, index = ix, class = c("xts", "zoo"))
+  m <- matrix(1:3, 3, 1, dimnames = list(format(.POSIXct(1:3)), "x"))
+  checkIdentical(as.matrix(x), m)
+}
